import getInfoFromHash from './getInfoFromHash';
import findLeafByHashPath from './findLeafByHashPath';

var filterSections = function filterSections(_ref) {
  var sections = _ref.sections,
      hashArray = _ref.hashArray;

  if (hashArray.length > 0) {
    var leaf = findLeafByHashPath(sections, hashArray);
    return leaf ? [leaf] : [];
  } else {
    return sections;
  }
};
/**
 * Return sections / components to show on a screen according to the current route.
 *
 * Default: show all sections and components.
 * Default with pagePerSection: show the first section or component.
 *
 * #/Button: show only Button section or Button component
 * #!/Button: show only Button section or Button component in isolated mode
 * #!/Button//1: show only the second example (index 1) of Button component in isolated mode
 */


export default function getRouteData(sections, // Hash part of the URL, including the # character
hash, // Should render a single section or component: pagePerSection option or isolated mode
pagePerSection) {
  if (pagePerSection === void 0) {
    pagePerSection = false;
  }

  var _getInfoFromHash = getInfoFromHash({
    sections: sections,
    hash: hash,
    pagePerSection: pagePerSection
  }),
      isolated = _getInfoFromHash.isolated,
      hashArray = _getInfoFromHash.hashArray,
      exampleIndex = _getInfoFromHash.exampleIndex;

  var filteredSections = filterSections({
    sections: sections,
    hashArray: hashArray
  });
  return {
    sections: filteredSections,
    isolated: isolated,
    exampleIndex: exampleIndex
  };
}